//************************************************************
//
// eventID.hh
//
/** @file eventID.hh
 *
 * @brief Event IDs.
 *
 * Define all event IDs we use at Telemotive.
 */
//************************************************************

#ifndef __EVENTID_HH__
#define __EVENTID_HH__

#if defined(__cplusplus)
#include <iostream>
#endif

/** @todo Add enum documentation.
 */

enum eventid_t
{
    EVID_NOT_SET = 0,

    /* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     * Start of the reserved RDB event sections.
     * All event ids within this section are RDB relevant.
     * !!! PLEASE do not insert general bpng events here !!!!!
     * --------------------------------------------------*/

    EVID_STARTUP		= 0x01,	///< bpng start up
    EVID_SHUTDOWN		= 0x02,	///< bpng shut down
    EVID_MARKER			= 0x03,	///< marker set
    EVID_MARKER_CLEAR		= 0x04,	///< all Markers are deleted
    EVID_INFO			= 0x05,	///< Info is set
    EVID_SLAVE_OFFSET		= 0x06,	///< cascading slave offset
    EVID_SLAVE_TO_MASTER	= 0x07,	///< cascading slave to master
    EVID_DATA_DELETED		= 0x08,	///< all data and data space is deleted
    EVID_TIME_SET		= 0x09,	///< bpng time was set
    EVID_NEW_TIME		= 0x0A,	///< new time
    EVID_SUDDEN_DEATH		= 0x0B,	///< no "real" shutdown was found after startup.
    EVID_TSL_SLAVE_OFFSET       = 0x0C, ///< slave is synced with master.
    EVID_TSL_SLAVE_TO_MASTER    = 0x0D, ///< slave is not synced with master.
    EVID_TSL_SESSION_START      = 0x0E, ///< start of a tsl synchronized session
    EVID_TSL_SESSION_END        = 0x0F, ///< end of a tsl synchronized session
    EVID_CONFIG			= 0x10, ///< configuration has been updated
    EVID_WAKEUP                 = 0x11, ///< bpng wake-up source

    // ------------------------------------------------
    // End of the reserved RDB event section

    EVID_RDB_SEC_END		= 30,	///< only for dynamic limit handling

    // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    // ------------------------------------------------
    // Start of the general NG Event section

    EVID_FILE_DELETED,		///< Only one file is deleted
    EVID_MARKERNUM_SET,         ///< The marker/trigger number is set to a new value

    EVID_INVALID	= -1
};


/// Different comment codes to tell die client why TSL changed to unsync state.
enum tslComment_t
{
    TSL_OK              = 0, ///< No error (normal behavior).
    TSL_TIMEOUT         = 1, ///< Timeout (normal behavior).
    TSL_OFFSET_ERR      = 2, ///< Offset was multiple time too high (error).
    TSL_SYSTEM_ERR      = 3, ///< Major system error.
};


#if defined(__cplusplus)
extern std::ostream &operator<< (std::ostream &os, eventid_t id);
extern eventid_t tmlibGetEventId(const std::string &_eventIdString);
#endif

#endif
